library(ggplot2)
library(grid)
library(ggrepel)
library(biplotr)
library(gridExtra)

fname <- "iroki_pca_dat.txt"
dat <- read.table(fname, header = TRUE, sep = "\t")

head(dat)
names <- dat$name
dat <- dat[, 2:4]
rownames(dat) <- names

bp <- pca_biplot(dat,
                 center_data = TRUE,
                 scale_data = TRUE,
                 point_labels = TRUE,
                 arrow_labels = TRUE,
                 arrow_labels_nudge_y = 0.75,
                 arrow_scaling_factor = 0.6,
                 use_ggrepel = TRUE,
                 limits_nudge_y = -1.5)

p <- bp$plot_elem$biplot_chart_base +
  theme_amelia() +
  geom_point() +
  geom_text_repel(aes(x = PC1,
                      y = PC2,
                      label=rownames(bp$plot_elem$data_for_ggplot)),
                  vjust = 0.5,
                  size = 3.5) +
  geom_segment(data = bp$plot_elem$loadings_df,
               mapping = aes(x = x, y = y, xend = xend, yend = yend),
               arrow = arrow(length = unit(0.25, "cm")),
               color = c("#583093", "#F36C19", "#056961")) +
  geom_text(data = bp$plot_elem$loadings_df,
            mapping = aes(x = xlabel,
                          y = ifelse(ylabel > 0, ylabel + 0.1, ylabel - 0.1),
                          label = bp$plot_elem$loadings_df$Variable),
            color = c("#583093", "#F36C19", "#056961"),
            vjust = 0.5,
            hjust = 0.5,
            check_overlap = FALSE,
            show.legend = FALSE,
            size = 3.5) +
  ggtitle("")
plot(p)

pdf_name <- "tara_pca_biplot_full.pdf"
pdf(pdf_name, height = 10, width = 15)
plot(p)
dev.off()